@@ -80,7 +80,7 @@ void ThemeEditorMainWindow::setupActions()
     KConfigGroup groupConfig = config->group(QStringLiteral("ThemeEditorMainWindow"));
     mRecentFileAction->loadEntries(groupConfig);
 
-    mAddExtraPage = new QAction(i18n("Add Extra Page..."), this);
+    mAddExtraPage = new QAction(i18nc("@action", "Add Extra Page..."), this);
     connect(mAddExtraPage, &QAction::triggered, this, &ThemeEditorMainWindow::slotAddExtraPage);
     actionCollection()->addAction(QStringLiteral("add_extra_page"), mAddExtraPage);
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
@@ -104,15 +104,15 @@ void ThemeEditorMainWindow::setupActions()
     KStandardAction::quit(this, &ThemeEditorMainWindow::slotQuitApp, actionCollection());
     KStandardAction::preferences(this, &ThemeEditorMainWindow::slotConfigure, actionCollection());
 
-    mInstallTheme = new QAction(i18n("Install theme"), this);
+    mInstallTheme = new QAction(i18nc("@action", "Install theme"), this);
     actionCollection()->addAction(QStringLiteral("install_theme"), mInstallTheme);
     connect(mInstallTheme, &QAction::triggered, this, &ThemeEditorMainWindow::slotInstallTheme);
 
-    mInsertFile = new QAction(i18n("Insert File..."), this);
+    mInsertFile = new QAction(i18nc("@action", "Insert File..."), this);
     actionCollection()->addAction(QStringLiteral("insert_file"), mInsertFile);
     connect(mInsertFile, &QAction::triggered, this, &ThemeEditorMainWindow::slotInsertFile);
 
-    mManageTheme = new QAction(i18n("Manage themes..."), this);
+    mManageTheme = new QAction(i18nc("@action", "Manage themes..."), this);
     connect(mManageTheme, &QAction::triggered, this, &ThemeEditorMainWindow::slotManageTheme);
     actionCollection()->addAction(QStringLiteral("manage_themes"), mManageTheme);
 
@@ -169,6 +169,7 @@ bool ThemeEditorMainWindow::slotSaveTheme()
 {
     bool result = false;
     if (mThemeEditor) {
+        mThemeEditor->slotChanged();
         result = mThemeEditor->saveTheme(false);
         mSaveAction->setEnabled(!result);
     }
